summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorArthur de Jong <arthur@arthurdejong.org>2014-06-12 22:28:21 +0200
committerArthur de Jong <arthur@arthurdejong.org>2014-06-12 23:51:23 +0200
commit9516479505bcc750b1e52ff40a96720496d48f61 (patch)
tree4939e2e275d6b25e2bcf7d562e521a8234bc6c1f /tests
parentb3cf0aa256c43c601b96eee76aa08ecca29629a0 (diff)
Use other IP range for tests
This uses IP addresses from the RFC 5737 TEST-NET-1 range that is meant for use in documentation. This avoids issues with running the tests environments that also use the 10.0.0.0/8 range.
Diffstat (limited to 'tests')
-rw-r--r--tests/test.ldif4
-rwxr-xr-xtests/test_nsscmds.sh24
2 files changed, 14 insertions, 14 deletions
diff --git a/tests/test.ldif b/tests/test.ldif
index e375c5b..d032b22 100644
--- a/tests/test.ldif
+++ b/tests/test.ldif
@@ -40174,7 +40174,7 @@ objectClass: ieee802Device
objectClass: device
cn: testhost
cn: testhostalias
-ipHostNumber: 10.0.0.1
+ipHostNumber: 192.0.2.123
macAddress: 0:18:8a:54:1a:8e
dn: cn=testhost2,ou=hosts,dc=test,dc=tld
@@ -40193,7 +40193,7 @@ dn: cn=testnet,ou=networks,dc=test,dc=tld
objectClass: top
objectClass: ipNetwork
cn: testnet
-ipNetworkNumber: 10.0.0.0
+ipNetworkNumber: 192.0.2.0
dn: ou=protocols,dc=test,dc=tld
objectClass: top
diff --git a/tests/test_nsscmds.sh b/tests/test_nsscmds.sh
index a86d9d8..5cd54c3 100755
--- a/tests/test_nsscmds.sh
+++ b/tests/test_nsscmds.sh
@@ -120,7 +120,7 @@ EOM
# get entry by ip address
# this does not currently work, but maybe it should
#check "getent ethers 10.0.0.1" << EOM
#0:18:8a:54:1a:8e testhost
#EOM
@@ -229,24 +229,24 @@ then
echo "test_nsscmds.sh: testing hosts..."
check "getent hosts testhost" << EOM
-10.0.0.1 testhost testhostalias
+192.0.2.123 testhost testhostalias
EOM
check "getent hosts testhostalias" << EOM
-10.0.0.1 testhost testhostalias
+192.0.2.123 testhost testhostalias
EOM
# check hostname with different case
check "getent hosts TESTHOST" << EOM
-10.0.0.1 testhost testhostalias
+192.0.2.123 testhost testhostalias
EOM
-check "getent hosts 10.0.0.1" << EOM
-10.0.0.1 testhost testhostalias
+check "getent hosts 192.0.2.123" << EOM
+192.0.2.123 testhost testhostalias
EOM
check "getent hosts | grep testhost" << EOM
-10.0.0.1 testhost testhostalias
+192.0.2.123 testhost testhostalias
EOM
# TODO: add more tests for IPv6 support
@@ -277,20 +277,20 @@ then
echo "test_nsscmds.sh: testing networks..."
check "getent networks testnet" << EOM
-testnet 10.0.0.0
+testnet 192.0.2.0
EOM
# check network name with different case
check "getent networks TESTNET" << EOM
-testnet 10.0.0.0
+testnet 192.0.2.0
EOM
-check "getent networks 10.0.0.0" << EOM
-testnet 10.0.0.0
+check "getent networks 192.0.2.0" << EOM
+testnet 192.0.2.0
EOM
check "getent networks | grep testnet" << EOM
-testnet 10.0.0.0
+testnet 192.0.2.0
EOM
fi # end of networks tests
@@ -120,7 +120,7 @@ EOM
# get entry by ip address
# this does not currently work, but maybe it should
-#check "getent ethers 10.0.0.1" << EOM
+#check "getent ethers 192.0.2.123" << EOM
#0:18:8a:54:1a:8e testhost
#EOM